@@ -173,14 +173,20 @@ class NotEqualFilterOperator(EqualFilterOperator):
 @dataclass
 class LessThanFilterOperator(BaseFilterOperator):
     def compare(self, event: Any) -> bool:
-        return self.target_value(event) < self.condition.value
+        target_value = self.target_value(event)
+        if target_value is None:
+            return False
+        return target_value < self.condition.value
 
 
 @op(">")
 @dataclass
 class GreaterThanFilterOperator(BaseFilterOperator):
     def compare(self, event: Any) -> bool:
-        return self.target_value(event) > self.condition.value
+        target_value = self.target_value(event)
+        if target_value is None:
+            return False
+        return target_value > self.condition.value
 
 
 @op(">=")
@@ -211,7 +217,10 @@ class LessThanOrEqualFilterOperator(LessThanFilterOperator):
 @dataclass
 class ContainsFilterOperator(BaseFilterOperator):
     def compare(self, event: Any) -> bool:
-        return self.condition.value in self.target_value(event)
+        target_value = self.target_value(event)
+        if target_value is None:
+            return False
+        return self.condition.value in target_value
 
 
 @op("!contains")
@@ -277,7 +286,10 @@ class InCIDRFilterOperator(BaseFilterOperator):
             self.condition.value = to_ip_network(self.condition.value)
             self.value_converted = True
 
-        lhs = to_ip_network(self.target_value(event))
+        target_value = self.target_value(event)
+        if target_value is None:
+            return False
+        lhs = to_ip_network(target_value)
         rhs = self.condition.value
 
         return lhs.overlaps(rhs)
@@ -310,6 +322,8 @@ class ContainsIPFilterOperator(BaseFilterOperator):
             self.condition.value = to_ip_network(self.condition.value)
             self.value_converted = True
         lhs = self.target_value(event)
+        if lhs is None:
+            return False
         if not is_list(lhs):
             raise FilterException(f"expected {self.condition.target} to be a list of ips")
 
